summaryrefslogtreecommitdiffstats
path: root/mailnews
diff options
context:
space:
mode:
Diffstat (limited to 'mailnews')
-rw-r--r--mailnews/addrbook/src/nsAbLDAPAutoCompleteSearch.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/mailnews/addrbook/src/nsAbLDAPAutoCompleteSearch.js b/mailnews/addrbook/src/nsAbLDAPAutoCompleteSearch.js
index 1c62d7e97..f75a57f0a 100644
--- a/mailnews/addrbook/src/nsAbLDAPAutoCompleteSearch.js
+++ b/mailnews/addrbook/src/nsAbLDAPAutoCompleteSearch.js
@@ -208,8 +208,8 @@ nsAbLDAPAutoCompleteSearch.prototype = {
acDirURI = Services.prefs.getCharPref("ldap_2.autoComplete.directoryServer");
}
- if (!acDirURI) {
- // No directory to search, send a no match and return.
+ if (!acDirURI || Services.io.offline) {
+ // No directory to search or we are offline, send a no match and return.
aListener.onSearchResult(this, this._result);
return;
}